# geometry-to-spatialite

![Run tests](https://github.com/chris48s/geometry-to-spatialite/workflows/Run%20tests/badge.svg?branch=master)
[![codecov](https://codecov.io/gh/chris48s/geometry-to-spatialite/branch/master/graph/badge.svg?token=Y15Y63PPM4)](https://codecov.io/gh/chris48s/geometry-to-spatialite)
[![PyPI Version](https://img.shields.io/pypi/v/geometry-to-spatialite.svg)](https://pypi.org/project/geometry-to-spatialite/)
![License](https://img.shields.io/pypi/l/geometry-to-spatialite.svg)
![Python Compatibility](https://img.shields.io/badge/dynamic/json?query=info.requires_python&label=python&url=https%3A%2F%2Fpypi.org%2Fpypi%2Fgeometry-to-spatialite%2Fjson)
![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)

Import geographic and spatial data from files into a SpatiaLite DB.

## 📚 [Documentation](https://chris48s.github.io/geometry-to-spatialite)
* [Installation](https://chris48s.github.io/geometry-to-spatialite/installation.html)
* [Usage](https://chris48s.github.io/geometry-to-spatialite/usage.html)
* [Troubleshooting](https://chris48s.github.io/geometry-to-spatialite/troubleshooting.html)
